<?php

header('Content-Type: application/json');
require_once(dirname(__FILE__) . '/../../includes/common.inc.php');

pre_init();
init_session(true);

grab_request_vars();
check_prereqs();
check_authentication(false, false, false, true);

$requestType = $_SERVER['REQUEST_METHOD'];
header('Content-Type: application/json');

switch ($requestType) {
    case 'GET':
        switch(grab_request_var("command", "")) {
            case "program":
                $response = get_program_status_xml_output(array(), true);
                break;
            case "system":
                $response = get_xml_sysstat_data();
                $response = json_decode(json_encode($response));

                // get_xml_sysstat_data() can return multiple 'daemons' entries under unknown circumstances. Limit this to the most recent one.
                if (property_exists($response, 'daemons')) {
                    if (is_array($response->daemons)) {
                        $response->daemons = $response->daemons[count($response->daemons) - 1];
                    }
                }

                // Kind of a hack - "output" seems to include sensitive information sometimes, 
                // so let's not display that to everyone. -swolf 2024-02-16
                // Let's also display the pre-translated text just in case the frontend wants it.

                if (property_exists($response, 'daemons') && property_exists($response->daemons, 'daemon')) {
                    for ($i = 0; $i < count($response->daemons->daemon); $i += 1) {
                        $daemon =& $response->daemons->daemon[$i]; // I gotta unset(), forgive me
                        if (property_exists($daemon, 'output')) {
                            unset($daemon->output);
                        }

                        switch ($daemon->{'@attributes'}->id) {
                            case "nagioscore": {
                                $daemon->display_name = _("Monitoring engine");
                            } break;
                            case "pnp": {
                                $daemon->display_name = _("Performance grapher");
                            } break;
                            default: {
                                $daemon->display_name = _("Unknown Daemon");
                            } break;
                        }
                        switch ($daemon->status) {
                            case SUBSYS_COMPONENT_STATUS_OK: {
                                $daemon->display_status = _("OK");
                                $daemon->display_running = _("Running");
                            } break;
                            case SUBSYS_COMPONENT_STATUS_ERROR: {
                                $daemon->display_status = _("Critical");
                                $daemon->display_running = _("Not running");
                            } break;
                            case SUBSYS_COMPONENT_STATUS_UNKNOWN: {
                                $daemon->display_status = _("Warning");
                                $daemon->display_running = _("Not running");
                            } break;

                        }
                    }
                }

            break;
            case "gethoststatus":
                global $request;
                $response = get_xml_host_status($request);
                if(!$response) {
                    $response = array( "recordcount" => 0 );
                }
                break;
            case "getservicestatus":
                global $request;
                $response = get_xml_service_status($request);
                if(!$response) {
                    $response = array( "recordcount" => 0 );
                }
                break;

            case "admincheck":
                $is_admin = is_admin();
                $response = array( "isAdmin" => $is_admin );
                break;

            case "updateversioncheck":
                $last_update_check_succeeded = get_option("last_update_check_succeeded");
                $update_available = get_option("update_available");
                $is_admin = is_admin();
                $hide_updates = false;
                if (custom_branding()) {
                    global $bcfg;
                    if ($bcfg['hide_updates']) {
                        $hide_updates = true;
                    }
                }
                $response = array(
                    "lastUpdateCheckSucceeded" => $last_update_check_succeeded,
                    "updateAvailable" => $update_available,
                    "isAdmin" => $is_admin,
                    "hideUpdates" => $hide_updates,
                );
                break;

            case "mismatchedipcheck":
                $server_ip_addr = $_SERVER['SERVER_ADDR'];
                // Get host/ip address from the internal url
                $host_or_ip = get_internal_url();
                preg_match('/:\/\/(.*)\//U', $host_or_ip, $clean);
                $host_or_ip = $clean[1];

                // Get IP from hostname if possible
                $could_not_resolve = false;
                if (!filter_var($host_or_ip, FILTER_VALIDATE_IP)) {
                    $ip = gethostbyname($host_or_ip);
                    if ($ip == $host_or_ip) {
                        $could_not_resolve = true;
                    } else {
                        $host_or_ip = $ip;
                    }
                }
                $mismatch_found = ($host_or_ip != $server_ip_addr);
                $response = array(
                    "could_not_resolve" => $could_not_resolve,
                    "mismatch_found" => $mismatch_found,
                );
                break;

            default:
                $response = array('error' => _('Invalid command'));
                break;
        }
        break;
    default:
        $response = array('error' => _('Invalid request method'));
        break;
}

$response = json_encode($response);
echo $response;